#
# spec file for package python-scikit-umfpack
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         oldpython python
Name:           python-scikit-umfpack
Version:        0.3.3
Release:        1.1
Summary:        Python interface to UMFPACK sparse direct solver
License:        BSD-3-Clause
URL:            https://github.com/scikit-umfpack/scikit-umfpack
Source0:        https://files.pythonhosted.org/packages/source/s/scikit-umfpack/scikit-umfpack-%{version}.tar.gz
# PATCH-FIX-UPSTREAM both patches sent upstream in  https://github.com/scikit-umfpack/scikit-umfpack/pull/87 NumPy 1.25 compatibility fixes
Patch0:         do-not-use-numpy-decorators.patch
Patch1:         numpy125.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel >= 1.14.3}
BuildRequires:  %{python_module scipy >= 1.0.0rc1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  gcc-fortran
BuildRequires:  openblas-devel
BuildRequires:  python-rpm-macros
BuildRequires:  suitesparse-devel
BuildRequires:  swig
Requires:       python-numpy >= 1.14.3
Requires:       python-scipy >= 1.0.0rc1
ExclusiveArch:  x86_64
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%ifpython2
Provides:       %{oldpython}-scikits-umfpack = %{version}
Obsoletes:      %{oldpython}-scikits-umfpack < %{version}
%endif
%python_subpackages

%description
The scikit-umfpack package provides wrapper of UMFPACK sparse direct solver to SciPy.

%prep
%setup -q -n scikit-umfpack-%{version}
%autopatch -p1
sed -i -e '/^#!\//, 1d' scikits/umfpack/setup.py
sed -i -e '/^#!\//, 1d' scikits/umfpack/tests/try_umfpack.py

%build
export LANG=en_US.UTF-8
export CFLAGS="%{optflags}"
%python_build

%install
export LANG=en_US.UTF-8
%python_install
%python_expand rm %{buildroot}%{$python_sitearch}/scikits/__init__.py*
%python_expand rm %{buildroot}%{$python_sitearch}/MANIFEST.in
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export LANG=en_US.UTF-8
export CFLAGS="%{optflags}"
%pytest_arch

%files %{python_files}
%doc README.rst
%license LICENSE
%dir %{python_sitearch}/scikits/
%{python_sitearch}/scikits/umfpack/
%{python_sitearch}/scikit_umfpack-%{version}*-info

%changelog
* Thu Aug 31 2023 Markéta Machová <mmachova@suse.com>
- update to 0.3.3
  * use scipy.sparse.linalg function without linsolve namespace
  * DOC: add citations to README.rst
- drop merged scikit-umfpack-pr68-scipy-sparse-linalg.patch
- add numpy125.patch
- Clean up the SPEC file.
* Sat Apr  2 2022 Ben Greiner <code@bnavigator.de>
- Add scikit-umfpack-pr68-scipy-sparse-linalg.patch
  gh#scikit-umfpack/scikit-umfpack#68
- x86_64 is the only platform where this works
* Thu Sep  9 2021 Steve Kowalik <steven.kowalik@suse.com>
- Switch from nose to pytest.
- Add do-not-use-numpy-decorators.patch:
  * The numpy decorators require nose, switch to unittest.skipIf()
* Sun Feb 14 2021 Dirk Müller <dmueller@suse.com>
- skip python36 (no scipy anymore)
* Fri Sep 20 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in the scikits.example
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to 0.3.2
  * replace non-ascii character
  * Remove hack for windows
* Thu May 24 2018 toddrme2178@gmail.com
- spec file cleanups
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to 0.3.1
  * FIX: replace scipy with scikit.umfpack
  * setup: require scipy 1.0
  * FIX: define Suitesparse_long as UF_long if not defined
  * BUG: type Suitesparse_long to be UF_long.
  * FIX: revert the int32 type conversion
  * setup: set the correct install_requires
  * FIX: use explicit bit-width types in UmfpackContext._getIndx()
  * BUG: fix UmfpackContext family selection in UmfpackLU.__init__()
  * replace suppress_warnings() by warnings.catch_warnings()
* Fri Jul 14 2017 toddrme2178@gmail.com
- Update to 0.3.0 official release
- Use the scikits namespace package
- Implement single-spec version
- Fix source URL.
* Mon Jan 11 2016 toddrme2178@gmail.com
- Use proper package name (python-scikit-umfpack)
- Update to 0.2.1 official release
- Implement update-alternatives for scikits/__init__.py
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Jun  3 2012 toddrme2178@gmail.com
- Clean up spec file
* Wed Mar  7 2012 scorot@free.fr
- build requires suitesparse-devel instead of umfpack-devel
* Thu Mar  3 2011 scorot@gtt.fr
- first package
